@@ -1,5 +1,3 @@
-from bzrlib import errors
-from bzrlib.bzrdir import BzrDir
 from bzrlib.transport import get_transport
 from bzrtools import list_branches
 
